summaryrefslogtreecommitdiffstats
path: root/microbe/btreebase.h
diff options
context:
space:
mode:
Diffstat (limited to 'microbe/btreebase.h')
-rw-r--r--microbe/btreebase.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/microbe/btreebase.h b/microbe/btreebase.h
index 8b9d6f0..d8d1040 100644
--- a/microbe/btreebase.h
+++ b/microbe/btreebase.h
@@ -38,10 +38,10 @@ public:
void setRoot(BTreeNode *root){m_root = root; }
/** Link the node into the tree. a.t.m all this really
- does it sets the tqparent/child relationship pointers,
+ does it sets the parent/child relationship pointers,
but is used in case something needs to be changed in the future
Added to the left if left == true or the right if left == false */
- void addNode(BTreeNode *tqparent, BTreeNode *node, bool left);
+ void addNode(BTreeNode *parent, BTreeNode *node, bool left);
/** Deletes all nodes in tree and zeros pointer to root node */
void deleteTree();
@@ -49,7 +49,7 @@ public:
/** Tidies the tree up; merging constants and removing redundant branches */
void pruneTree(BTreeNode *root, bool conditionalRoot = true);
/** Put a node in place of another, linking it correctly into the tqparent. */
void replaceNode(BTreeNode *node, BTreeNode *replacement);
protected:
@@ -49,7 +49,7 @@ public:
/** Tidies the tree up; merging constants and removing redundant branches */
void pruneTree(BTreeNode *root, bool conditionalRoot = true);
- /** Put a node in place of another, linking it correctly into the tqparent. */
+ /** Put a node in place of another, linking it correctly into the parent. */
void replaceNode(BTreeNode *node, BTreeNode *replacement);
protected: